@@ -1,15 +1,16 @@
 package builds
 
 import (
+	"context"
 	"fmt"
 	"time"
 
 	v1 "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/serializer"
 	"k8s.io/apimachinery/pkg/util/wait"
-	e2e "k8s.io/kubernetes/test/e2e/framework"
 
 	g "github.com/onsi/ginkgo"
 	o "github.com/onsi/gomega"
@@ -22,7 +23,7 @@ import (
 
 // e2e tests of the build controller configuration.
 // These are tagged [Serial] because each test modifies the cluster-wide build controller config.
-var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via cluster configuration", func() {
+var _ = g.Describe("[sig-builds][Feature:Builds][Serial][Slow][Disruptive] alter builds via cluster configuration", func() {
 	defer g.GinkgoRecover()
 	var (
 		buildFixture              = exutil.FixturePath("testdata", "builds", "test-build.yaml")
@@ -31,7 +32,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 		blacklistConfigFixture    = exutil.FixturePath("testdata", "builds", "cluster-config", "registry-blacklist.yaml")
 		whitelistConfigFixture    = exutil.FixturePath("testdata", "builds", "cluster-config", "registry-whitelist.yaml")
 		invalidproxyConfigFixture = exutil.FixturePath("testdata", "builds", "cluster-config", "invalid-build-cluster-config.yaml")
-		oc                        = exutil.NewCLI("build-cluster-config", exutil.KubeConfigPath())
+		oc                        = exutil.NewCLI("build-cluster-config")
 		checkPodProxyEnvs         = func(containers []v1.Container, proxySpec *configv1.ProxySpec) {
 			o.Expect(containers).NotTo(o.BeNil())
 			foundHTTP := false
@@ -57,8 +58,8 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 		checkOCMProgressing = func(progressing operatorv1.ConditionStatus) {
 			g.By("check that the OCM enters Progressing==" + string(progressing))
 			var err error
-			err = wait.Poll(1*time.Second, 2*time.Minute, func() (bool, error) {
-				ocm, err := oc.AdminOperatorClient().OperatorV1().OpenShiftControllerManagers().Get("cluster", metav1.GetOptions{})
+			err = wait.Poll(5*time.Second, 10*time.Minute, func() (bool, error) {
+				ocm, err := oc.AdminOperatorClient().OperatorV1().OpenShiftControllerManagers().Get(context.Background(), "cluster", metav1.GetOptions{})
 				if err != nil {
 					g.By("intermediate error accessing ocm: " + err.Error())
 					return false, nil
@@ -72,45 +73,11 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 			})
 			o.Expect(err).NotTo(o.HaveOccurred())
 		}
-		checkDSRolloutState = func(inProgress bool) {
-			g.By(fmt.Sprintf("check that a OCM DS rollout being in progress is %v", inProgress))
-			var err error
-			err = wait.Poll(1*time.Second, 2*time.Minute, func() (bool, error) {
-				ds, err := oc.AdminKubeClient().AppsV1().DaemonSets("openshift-controller-manager").Get("controller-manager", metav1.GetOptions{})
-				if err != nil {
-					g.By("intermediate error access ds: " + err.Error())
-					return false, nil
-				}
-				if inProgress {
-					if ds.Status.CurrentNumberScheduled < ds.Status.DesiredNumberScheduled ||
-						ds.Status.NumberReady < ds.Status.DesiredNumberScheduled ||
-						ds.Status.NumberAvailable < ds.Status.DesiredNumberScheduled ||
-						ds.Status.UpdatedNumberScheduled < ds.Status.DesiredNumberScheduled {
-						return true, nil
-					}
-					return false, nil
-				}
-				if ds.Status.CurrentNumberScheduled == ds.Status.DesiredNumberScheduled &&
-					ds.Status.NumberReady == ds.Status.DesiredNumberScheduled &&
-					ds.Status.NumberAvailable == ds.Status.DesiredNumberScheduled &&
-					ds.Status.UpdatedNumberScheduled == ds.Status.DesiredNumberScheduled {
-					return true, nil
-				}
-				e2e.Logf("ocm Desired: %d, Current: %d, Ready: %d, Available: %d, Updated: %d",
-					ds.Status.DesiredNumberScheduled,
-					ds.Status.CurrentNumberScheduled,
-					ds.Status.NumberReady,
-					ds.Status.NumberAvailable,
-					ds.Status.UpdatedNumberScheduled)
-				return false, nil
-			})
-			o.Expect(err).NotTo(o.HaveOccurred())
-		}
 		checkBuildPodUnschedulable = func(name string) {
 			g.By(fmt.Sprintf("check the build pod %s is unschedulable", name))
 			var err error
 			err = wait.Poll(1*time.Second, 2*time.Minute, func() (bool, error) {
-				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(name, metav1.GetOptions{})
+				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(context.Background(), name, metav1.GetOptions{})
 				if err != nil {
 					g.By("intermediate error access pod: " + err.Error())
 					return false, nil
@@ -149,6 +116,42 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 			o.Expect(ok).To(o.BeTrue())
 			return build
 		}
+		checkPodResource = func(containers []v1.Container, resources configv1.BuildDefaults) {
+			defaultResources := resources.Resources
+			o.Expect(containers).NotTo(o.BeNil())
+			foundLimitCpu := false
+			foundLimitMem := false
+			foundRequestCpu := false
+			foundRequestMem := false
+			for _, container := range containers {
+				g.By(fmt.Sprintf("checking resources of container %s", container.Name))
+				o.Expect(container.Resources).NotTo(o.BeNil())
+				for name, value := range defaultResources.Limits {
+					if name == "cpu" {
+						foundLimitCpu = true
+						o.Expect(container.Resources.Limits[v1.ResourceName(name)]).To(o.Equal(value))
+					}
+					if name == "memory" {
+						foundLimitMem = true
+						o.Expect(container.Resources.Limits[v1.ResourceName(name)]).To(o.Equal(value))
+					}
+				}
+				for name, value := range defaultResources.Requests {
+					if name == "cpu" {
+						foundRequestCpu = true
+						o.Expect(container.Resources.Requests[v1.ResourceName(name)]).To(o.Equal(value))
+					}
+					if name == "memory" {
+						foundRequestMem = true
+						o.Expect(container.Resources.Requests[v1.ResourceName(name)]).To(o.Equal(value))
+					}
+				}
+			}
+			o.Expect(foundLimitCpu).To(o.BeTrue())
+			o.Expect(foundLimitMem).To(o.BeTrue())
+			o.Expect(foundRequestCpu).To(o.BeTrue())
+			o.Expect(foundRequestMem).To(o.BeTrue())
+		}
 	)
 
 	g.Context("", func() {
@@ -240,11 +243,11 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 		g.Context("build config no ocm rollout", func() {
 			g.AfterEach(func() {
 				g.By("reset build cluster configuration")
-				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				buildConfig.Spec.BuildDefaults = configv1.BuildDefaults{}
 				buildConfig.Spec.BuildOverrides = configv1.BuildOverrides{}
-				_, err = oc.AdminConfigClient().ConfigV1().Builds().Update(buildConfig)
+				_, err = oc.AdminConfigClient().ConfigV1().Builds().Update(context.Background(), buildConfig, metav1.UpdateOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 			})
 
@@ -255,7 +258,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				g.By("waiting 10s for build controller to detect proxy cfg chg")
 				time.Sleep(10 * time.Second)
 				g.By("verify build.config is set")
-				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(buildConfig.Spec.BuildDefaults.DefaultProxy).NotTo(o.BeNil())
 				g.By("starting build verbose-s2i-build and waiting for failure")
@@ -267,7 +270,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(buildLog).To(o.ContainSubstring("proxyconnect tcp: dial tcp: lookup invalid.proxy.redhat.com"))
 				g.By("checking pod as well")
-				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(br.BuildName+"-build", metav1.GetOptions{})
+				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(context.Background(), br.BuildName+"-build", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				checkPodProxyEnvs(pod.Spec.Containers, buildConfig.Spec.BuildDefaults.DefaultProxy)
 				checkPodProxyEnvs(pod.Spec.InitContainers, buildConfig.Spec.BuildDefaults.DefaultProxy)
@@ -280,7 +283,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				g.By("waiting 10s for build controller to detect proxy cfg chg")
 				time.Sleep(10 * time.Second)
 				g.By("verify build.config is set")
-				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(buildConfig.Spec.BuildDefaults.DefaultProxy).NotTo(o.BeNil())
 				g.By("starting build simple-s2i-build and waiting for failure")
@@ -290,9 +293,9 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				g.By("expecting the build logs to indicate invalid proxy")
 				buildLog, err := br.LogsNoTimestamp()
 				o.Expect(err).NotTo(o.HaveOccurred())
-				o.Expect(buildLog).To(o.ContainSubstring("Could not resolve proxy: invalid.proxy.redhat.com; Unknown error"))
+				o.Expect(buildLog).To(o.ContainSubstring("Could not resolve proxy: invalid.proxy.redhat.com"))
 				g.By("checking pod as well")
-				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(br.BuildName+"-build", metav1.GetOptions{})
+				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(context.Background(), br.BuildName+"-build", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				checkPodProxyEnvs(pod.Spec.Containers, buildConfig.Spec.BuildDefaults.DefaultProxy)
 				checkPodProxyEnvs(pod.Spec.InitContainers, buildConfig.Spec.BuildDefaults.DefaultProxy)
@@ -301,19 +304,19 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 			// this replaces coverage from the TestBuildDefaultGitHTTPProxy and TestBuildDefaultGitHTTPSProxy integration test
 			g.It("Apply git proxy configuration to build pod", func() {
 				g.By("apply proxy cluster configuration")
-				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				buildConfig.Spec.BuildDefaults.GitProxy = &configv1.ProxySpec{
 					HTTPProxy:  "http://invalid.proxy.redhat.com:3288",
 					HTTPSProxy: "https://invalid.proxy.redhat.com:3288",
 					NoProxy:    "image-registry.openshift-image-registry.svc:5000",
 				}
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(buildConfig)
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(context.Background(), buildConfig, metav1.UpdateOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				g.By("waiting 10s for build controller to detect proxy cfg chg")
 				time.Sleep(10 * time.Second)
 				g.By("verify build.config is set")
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(buildConfig.Spec.BuildDefaults.GitProxy).NotTo(o.BeNil())
 
@@ -324,11 +327,11 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				g.By("expecting the build logs to indicate invalid proxy")
 				buildLog, err := br.LogsNoTimestamp()
 				o.Expect(err).NotTo(o.HaveOccurred())
-				o.Expect(buildLog).To(o.ContainSubstring("Could not resolve proxy: invalid.proxy.redhat.com; Unknown error"))
+				o.Expect(buildLog).To(o.ContainSubstring("Could not resolve proxy: invalid.proxy.redhat.com"))
 				g.By("checking build stored in pod as well")
 				// note, only the build stored in the Pod's "BUILD" env var has the updated proxy settings; they do not
 				// get propagated to the associated build stored in etcd
-				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(br.BuildName+"-build", metav1.GetOptions{})
+				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(context.Background(), br.BuildName+"-build", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				build := getBuildFromPod(pod)
 				o.Expect(build.Spec.Source.Git).NotTo(o.BeNil())
@@ -342,22 +345,20 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 
 			g.AfterEach(func() {
 				g.By("reset build cluster configuration")
-				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				buildConfig.Spec.BuildDefaults = configv1.BuildDefaults{}
 				buildConfig.Spec.BuildOverrides = configv1.BuildOverrides{}
-				_, err = oc.AdminConfigClient().ConfigV1().Builds().Update(buildConfig)
+				_, err = oc.AdminConfigClient().ConfigV1().Builds().Update(context.Background(), buildConfig, metav1.UpdateOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				checkOCMProgressing(operatorv1.ConditionTrue)
 				checkOCMProgressing(operatorv1.ConditionFalse)
-				checkDSRolloutState(true)
-				checkDSRolloutState(false)
 			})
 
 			// this replaces coverage from the TestBuildDefaultEnvironment integration test
 			g.It("Apply env configuration to build pod", func() {
 				g.By("apply env cluster configuration")
-				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				buildConfig.Spec.BuildDefaults.Env = []v1.EnvVar{
 					{
@@ -369,17 +370,12 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 						Value: "VALUE2",
 					},
 				}
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(buildConfig)
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(context.Background(), buildConfig, metav1.UpdateOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				checkOCMProgressing(operatorv1.ConditionTrue)
 				checkOCMProgressing(operatorv1.ConditionFalse)
-				checkDSRolloutState(true)
-				checkDSRolloutState(false)
-				// there is no way programmatically to check leader election outcome
-				g.By("waiting 10s for controller-manager leader election to complete")
-				time.Sleep(10 * time.Second)
 				g.By("verify build.config is set")
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(buildConfig.Spec.BuildDefaults.Env).NotTo(o.BeNil())
 				o.Expect(len(buildConfig.Spec.BuildDefaults.Env)).To(o.Equal(2))
@@ -393,7 +389,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				o.Expect(err).NotTo(o.HaveOccurred())
 				br.AssertSuccess()
 				g.By("checking build obj env field")
-				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(br.BuildName+"-build", metav1.GetOptions{})
+				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(context.Background(), br.BuildName+"-build", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				build := getBuildFromPod(pod)
 				o.Expect(build.Spec.Strategy.SourceStrategy).NotTo(o.BeNil())
@@ -415,7 +411,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 			// this replaces coverage from the TestBuildDefaultLabels integration test
 			g.It("Apply default image label configuration to build pod", func() {
 				g.By("apply label cluster configuration")
-				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				buildConfig.Spec.BuildDefaults.ImageLabels = []configv1.ImageLabel{
 					{
@@ -427,17 +423,12 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 						Value: "VALUE2",
 					},
 				}
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(buildConfig)
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(context.Background(), buildConfig, metav1.UpdateOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				checkOCMProgressing(operatorv1.ConditionTrue)
 				checkOCMProgressing(operatorv1.ConditionFalse)
-				checkDSRolloutState(true)
-				checkDSRolloutState(false)
-				// there is no way programmatically to check leader election outcome
-				g.By("waiting 10s for controller-manager leader election to complete")
-				time.Sleep(10 * time.Second)
 				g.By("verify build.config is set")
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(buildConfig.Spec.BuildDefaults.ImageLabels).NotTo(o.BeNil())
 				o.Expect(len(buildConfig.Spec.BuildDefaults.ImageLabels)).To(o.Equal(2))
@@ -453,7 +444,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				g.By("checking build stored in pod as well")
 				// note, only the build stored in the Pod's "BUILD" env var has the updated proxy settings; they do not
 				// get propagated to the associated build stored in etcd
-				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(br.BuildName+"-build", metav1.GetOptions{})
+				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(context.Background(), br.BuildName+"-build", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				build := getBuildFromPod(pod)
 				o.Expect(build.Spec.Output.ImageLabels).NotTo(o.BeNil())
@@ -474,7 +465,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 			// this replaces coverage from the TestBuildOverrideLabels integration test
 			g.It("Apply override image label configuration to build pod", func() {
 				g.By("apply label cluster configuration")
-				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				buildConfig.Spec.BuildOverrides.ImageLabels = []configv1.ImageLabel{
 					{
@@ -486,17 +477,12 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 						Value: "VALUE2",
 					},
 				}
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(buildConfig)
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(context.Background(), buildConfig, metav1.UpdateOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				checkOCMProgressing(operatorv1.ConditionTrue)
 				checkOCMProgressing(operatorv1.ConditionFalse)
-				checkDSRolloutState(true)
-				checkDSRolloutState(false)
-				// there is no way programmatically to check leader election outcome
-				g.By("waiting 10s for controller-manager leader election to complete")
-				time.Sleep(10 * time.Second)
 				g.By("verify build.config is set")
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(buildConfig.Spec.BuildOverrides.ImageLabels).NotTo(o.BeNil())
 				o.Expect(len(buildConfig.Spec.BuildOverrides.ImageLabels)).To(o.Equal(2))
@@ -513,7 +499,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				g.By("checking build stored in pod as well")
 				// note, only the build stored in the Pod's "BUILD" env var has the updated proxy settings; they do not
 				// get propagated to the associated build stored in etcd
-				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(br.BuildName+"-build", metav1.GetOptions{})
+				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(context.Background(), br.BuildName+"-build", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				build := getBuildFromPod(pod)
 				o.Expect(build.Spec.Output.ImageLabels).NotTo(o.BeNil())
@@ -534,22 +520,17 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 			// this replaces coverage from the TestBuildDefaultNodeSelectors integration test
 			g.It("Apply node selector configuration to build pod", func() {
 				g.By("apply node selector cluster configuration")
-				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				selectors := map[string]string{"KEY": "VALUE", v1.LabelOSStable: "linux"}
 				buildConfig.Spec.BuildOverrides.NodeSelector = selectors
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(buildConfig)
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(context.Background(), buildConfig, metav1.UpdateOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 
 				checkOCMProgressing(operatorv1.ConditionTrue)
 				checkOCMProgressing(operatorv1.ConditionFalse)
-				checkDSRolloutState(true)
-				checkDSRolloutState(false)
-				// there is no way programmatically to check leader election outcome
-				g.By("waiting 10s for controller-manager leader election to complete")
-				time.Sleep(10 * time.Second)
 				g.By("verify build.config is set")
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(buildConfig.Spec.BuildOverrides.NodeSelector).NotTo(o.BeNil())
 				o.Expect(len(buildConfig.Spec.BuildOverrides.NodeSelector)).To(o.Equal(2))
@@ -558,7 +539,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				br, err := exutil.StartBuildAndWait(oc, "simple-s2i-build")
 				o.Expect(err).NotTo(o.HaveOccurred())
 				g.By("checking build pod node selector")
-				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(br.BuildName+"-build", metav1.GetOptions{})
+				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(context.Background(), br.BuildName+"-build", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(pod.Spec.NodeSelector).NotTo(o.BeNil())
 				val, ok := pod.Spec.NodeSelector["KEY"]
@@ -573,7 +554,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 			// this replaces coverage from the TestBuildOverrideTolerations integration test
 			g.It("Apply toleration override configuration to build pod", func() {
 				g.By("apply toleration cluster configuration")
-				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				tolerations := []v1.Toleration{
 					{
@@ -591,18 +572,13 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				}
 
 				buildConfig.Spec.BuildOverrides.Tolerations = tolerations
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(buildConfig)
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Update(context.Background(), buildConfig, metav1.UpdateOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 
 				checkOCMProgressing(operatorv1.ConditionTrue)
 				checkOCMProgressing(operatorv1.ConditionFalse)
-				checkDSRolloutState(true)
-				checkDSRolloutState(false)
-				// there is no way programmatically to check leader election outcome
-				g.By("waiting 10s for controller-manager leader election to complete")
-				time.Sleep(10 * time.Second)
 				g.By("verify build.config is set")
-				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get("cluster", metav1.GetOptions{})
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(buildConfig.Spec.BuildOverrides.Tolerations).NotTo(o.BeNil())
 				o.Expect(len(buildConfig.Spec.BuildOverrides.Tolerations)).To(o.Equal(2))
@@ -612,7 +588,7 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				o.Expect(err).NotTo(o.HaveOccurred())
 				br.AssertSuccess()
 				g.By("checking build pod tolerations")
-				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(br.BuildName+"-build", metav1.GetOptions{})
+				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(context.Background(), br.BuildName+"-build", metav1.GetOptions{})
 				o.Expect(err).NotTo(o.HaveOccurred())
 				o.Expect(pod.Spec.Tolerations).NotTo(o.BeNil())
 				foundOne := false
@@ -629,6 +605,55 @@ var _ = g.Describe("[Feature:Builds][Serial][Slow][Disruptive] alter builds via
 				o.Expect(foundTwo).To(o.BeTrue())
 			})
 
+			g.It("Apply resource configuration to build pod", func() {
+				g.By("apply resource cluster configuration")
+				buildConfig, err := oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
+				o.Expect(err).NotTo(o.HaveOccurred())
+				limits := map[v1.ResourceName]resource.Quantity{v1.ResourceCPU: resource.MustParse("500m"), v1.ResourceMemory: resource.MustParse("2Gi")}
+				requests := map[v1.ResourceName]resource.Quantity{v1.ResourceCPU: resource.MustParse("100m"), v1.ResourceMemory: resource.MustParse("1Gi")}
+				buildConfig.Spec.BuildDefaults.Resources.Limits = limits
+				buildConfig.Spec.BuildDefaults.Resources.Requests = requests
+				oc.AdminConfigClient().ConfigV1().Builds().Update(context.Background(), buildConfig, metav1.UpdateOptions{})
+				o.Expect(err).NotTo(o.HaveOccurred())
+				checkOCMProgressing(operatorv1.ConditionTrue)
+				checkOCMProgressing(operatorv1.ConditionFalse)
+				g.By("verify build.config is set")
+				buildConfig, err = oc.AdminConfigClient().ConfigV1().Builds().Get(context.Background(), "cluster", metav1.GetOptions{})
+				o.Expect(err).NotTo(o.HaveOccurred())
+				o.Expect(buildConfig.Spec.BuildDefaults.Resources.Limits).NotTo(o.BeNil())
+				o.Expect(len(buildConfig.Spec.BuildDefaults.Resources.Limits)).To(o.Equal(2))
+				o.Expect(buildConfig.Spec.BuildDefaults.Resources.Requests).NotTo(o.BeNil())
+				o.Expect(len(buildConfig.Spec.BuildDefaults.Resources.Requests)).To(o.Equal(2))
+				g.By("create limitrange")
+				_, err = oc.AdminKubeClient().CoreV1().LimitRanges(oc.Namespace()).Create(context.Background(), &v1.LimitRange{
+					ObjectMeta: metav1.ObjectMeta{
+						Name: "limitrange",
+					},
+					Spec: v1.LimitRangeSpec{
+						Limits: []v1.LimitRangeItem{
+							{
+								Type: v1.LimitTypeContainer,
+								Default: v1.ResourceList{
+									v1.ResourceMemory: resource.MustParse("512Mi"),
+									v1.ResourceCPU:    resource.MustParse("250m"),
+								},
+							},
+						},
+					},
+				}, metav1.CreateOptions{})
+				o.Expect(err).NotTo(o.HaveOccurred())
+				g.By("starting build simple-s2i-build and waiting for completion")
+				br, err := exutil.StartBuildAndWait(oc, "simple-s2i-build")
+				o.Expect(err).NotTo(o.HaveOccurred())
+				br.AssertSuccess()
+				g.By("checking build pod resources are set correctly from build default")
+				pod, err := oc.KubeClient().CoreV1().Pods(oc.Namespace()).Get(context.Background(), br.BuildName+"-build", metav1.GetOptions{})
+				o.Expect(err).NotTo(o.HaveOccurred())
+				o.Expect(pod.Spec.Containers[0].Resources).NotTo(o.BeNil())
+				o.Expect(pod.Spec.InitContainers[0].Resources).NotTo(o.BeNil())
+				checkPodResource(pod.Spec.Containers, buildConfig.Spec.BuildDefaults)
+				checkPodResource(pod.Spec.InitContainers, buildConfig.Spec.BuildDefaults)
+			})
 		})
 	})
 })
